(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    137467,       4157]
NotebookOptionsPosition[     86126,       2898]
NotebookOutlinePosition[    120503,       3665]
CellTagsIndexPosition[    120423,       3660]
WindowTitle->S19 Discrete Calculus with Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "Discrete Calculus with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Title"],

Cell[TextData[{
 StyleBox["Wolfram",
  FontSlant->"Plain"],
 " ",
 StyleBox["Online Seminar Series",
  FontColor->RGBColor[0.811765, 0.117647, 0.145098]]
}], "Subtitle"],

Cell[TextData[{
 StyleBox["Presenter:",
  FontSlant->"Plain"],
 " Devendra Kapadia\nseminars@wolfram.com"
}], "Subsubtitle"],

Cell[TextData[{
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[
     DateString[], FontFamily -> "Calibri"], StandardForm],
   ImageSizeCache->{275., {3., 17.}},
   UpdateInterval:>1]]],
 StyleBox["  (GMT ",
  StripOnInput->False,
  FontFamily->"Calibri"],
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[$TimeZone, FontFamily -> "Calibri"], StandardForm],
   ImageSizeCache->{35., {1., 16.}}]]],
 ")"
}], "DateSection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Goals of this Seminar", "Section"],

Cell["In this talk, I would like to:", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "Give an introduction to discrete calculus operations using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Item"],

Cell["Discuss some interesting applications to practical problems", "Item"],

Cell["\<\
Provide insight into the internals of discrete calculus functions\
\>", "Item"],

Cell["\<\
Take a tour of the documentation and give suggestions for projects\
\>", "Item"],

Cell["\<\
Use symbolic, numerical, and graphical techniques for understanding concepts \
in discrete calculus\
\>", "Item"],

Cell[TextData[{
 "Show the great depth and utility of discrete calculus using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " "
}], "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Overview of Discrete Calculus", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["What is discrete calculus?", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell["\<\
Discrete calculus is the study of sequences using finite differences, sums, \
products, and generating functions.\
\>", "Item"],

Cell["\<\
Practical problems typically require the solution of difference equations \
given some initial or boundary conditions.\
\>", "Item"],

Cell["\<\
Many fields such as probability theory, dynamical systems, and numerical \
analysis use methods from discrete calculus.\
\>", "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sequences", "MoreExamplesSection"],

Cell[TextData[{
 "Every term in the ",
 ButtonBox["Fibonacci",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Fibonacci"],
 " sequence is the sum of the previous two terms in the sequence."
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"Table", "[", 
   RowBox[{
    TemplateBox[{"n"},
     "Fibonacci"], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell["\<\
The harmonic numbers are defined as the sums of reciprocals of natural \
numbers.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.4444892874336233`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Table", "[", 
   RowBox[{
    TemplateBox[{"n"},
     "HarmonicNumber"], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell["The sequence of harmonic numbers grows rather slowly.", "MathCaption",
 CellChangeTimes->{{3.4444893746721783`*^9, 3.444489393330496*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"DiscretePlot", "[", 
   RowBox[{
    TemplateBox[{"n"},
     "HarmonicNumber"], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "30"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red"}], "]"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4990908074770803`*^9, 3.499090813779723*^9}}],

Cell[TextData[{
 "Sequences such as ",
 ButtonBox["Factorial",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Factorial"],
 " and ",
 ButtonBox["BarnesG ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BarnesG"],
 "grow very quickly."
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.4444892874336233`*^9}, {3.44448942308084*^9, 3.4444894294926867`*^9}, {
  3.4444984947396727`*^9, 3.444498501338726*^9}, {3.4446706375256453`*^9, 
  3.4446706608797436`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"n", "!"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Table", "[", 
   RowBox[{
    TemplateBox[{"n"},
     "BarnesG"], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell["\<\
Hypergeometric functions often have simple expressions for certain discrete \
ranges of their parameters.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.4444892874336233`*^9}, {3.44448942308084*^9, 3.4444894294926867`*^9}, {
  3.44448950367354*^9, 3.4444895111774282`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","x"},
    "Hypergeometric2F1"], "/.", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"a", "\[Rule]", 
     RowBox[{"-", "2"}]}], "}"}]}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sums", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
  3.4316964360906043`*^9, 3.431696438961115*^9}}],

Cell["\<\
The sum of the squares of the first billion natural numbers can be computed \
in two ways:\
\>", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], 
    SuperscriptBox["10", "9"]], 
   SuperscriptBox["k", "2"]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "n"], 
   SuperscriptBox["k", "2"]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"%", "/.", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", 
     SuperscriptBox["10", "9"]}], "}"}]}], TraditionalForm]], "Input"],

Cell["\<\
The following multiple sum has a simple answer due to  a symmetry in the \
denominator:\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, {
  3.4444896264970636`*^9, 3.4444896335641356`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"m", "=", "1"}], "\[Infinity]"], 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["m", "2"], " ", "n"}], 
     RowBox[{
      SuperscriptBox["2", "m"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"m", " ", 
         SuperscriptBox["2", "n"]}], "+", 
        RowBox[{
         SuperscriptBox["2", "m"], " ", "n"}]}], ")"}]}]]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.445009144583329*^9, 3.4450091485461607`*^9}}],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Products", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
  3.431696431628833*^9, 3.431696433407301*^9}}],

Cell[TextData[{
 "This product defines the ",
 ButtonBox["Factorial",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Factorial"],
 " function."
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Product]", 
    RowBox[{"k", "=", "1"}], "n"], "k"}], TraditionalForm]], "Input"],

Cell["\<\
The following infinite product has a remarkably simple answer!\
\>", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Product]", 
    RowBox[{"k", "=", "2"}], "\[Infinity]"], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], "-", "1"}], 
       SuperscriptBox["k", "2"]], ")"}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "-", "1"}], ")"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"k", "+", "1"}], 
       RowBox[{"k", "-", "1"}]], ")"}], "k"]}]}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Difference equations", "MoreExamplesSection"],

Cell[TextData[{
 "This difference equation generates the ",
 ButtonBox["Fibonacci",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Fibonacci"],
 " sequence."
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"RSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "(", "n", ")"}], "\[LongEqual]", 
       RowBox[{
        RowBox[{"a", "(", 
         RowBox[{"n", "-", "2"}], ")"}], "+", 
        RowBox[{"a", "(", 
         RowBox[{"n", "-", "1"}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"a", "(", "1", ")"}], "\[LongEqual]", "1"}], ",", 
      RowBox[{
       RowBox[{"a", "(", "2", ")"}], "\[LongEqual]", "1"}]}], "}"}], ",", "a",
     ",", "n"}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "(", "n", ")"}], "/.", "\[InvisibleSpace]", 
     RowBox[{"%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 "The number of moves required to solve the ",
 ButtonBox["Towers of Hanoi",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/TowersOfHanoi/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/TowersOfHanoi/"],
 " puzzle with ",
 StyleBox["n",
  FontSlant->"Italic"],
 " disks and three rods is given by:"
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, {
  3.4444898880518045`*^9, 3.444489895524492*^9}, {3.4444899467256613`*^9, 
  3.444489953153108*^9}, {3.444670804435817*^9, 3.444670804437817*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"RSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"T", "(", "n", ")"}], "\[LongEqual]", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"T", "(", 
          RowBox[{"n", "-", "1"}], ")"}]}], "+", "1"}]}], ",", 
      RowBox[{
       RowBox[{"T", "(", "1", ")"}], "\[LongEqual]", "1"}]}], "}"}], ",", "T",
     ",", "n"}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"T", "(", "n", ")"}], "/.", "\[InvisibleSpace]", 
    RowBox[{"%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "/.",
    "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", "4"}], "}"}]}], TraditionalForm]], "Input"],

Cell[TextData[{
 "We can use ",
 ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"],
 " to generate the moves for different values of  ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ":"
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{"RecurrenceTable", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"T", "(", "n", ")"}], "\[LongEqual]", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"T", "(", 
          RowBox[{"n", "-", "1"}], ")"}]}], "+", "1"}]}], ",", 
      RowBox[{
       RowBox[{"T", "(", "1", ")"}], "\[LongEqual]", "1"}]}], "}"}], ",", "T",
     ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "10"}], "}"}]}], "]"}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["A Gallery of Sequences", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Polynomial sequences", "MoreExamplesSection"],

Cell["Here is a sequence of polynomials.", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.444489252971898*^9}, {3.4444982408243065`*^9, 3.4444982413079257`*^9}, {
  3.4446594383605857`*^9, 3.4446594428535585`*^9}, {3.44465948865692*^9, 
  3.444659507752054*^9}, {3.444659657299406*^9, 3.4446596881417923`*^9}, {
  3.4446597430871058`*^9, 3.4446597490465345`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"p", "(", "k_", ")"}], ":=", 
   RowBox[{
    RowBox[{"5", " ", 
     SuperscriptBox["k", "3"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["k", "2"]}], "+", 
    RowBox[{"11", " ", "k"}], "+", "7"}]}], TraditionalForm]], "Input"],

Cell["The higher-order differences of such a sequence vanish.", "MathCaption",
 CellChangeTimes->{{3.4439758215574856`*^9, 3.4439758464716434`*^9}, {
  3.444736801239229*^9, 3.4447368030488987`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"TraditionalForm", "[", 
   TemplateBox[{RowBox[{"f", "(", "k", ")"}],"k"},
    "DifferenceDelta2"], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Table", "[", 
   RowBox[{
    TemplateBox[{RowBox[{"p", "(", "k", ")"}],"k","i"},
     "DifferenceDelta3"], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}]}], "]"}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hypergeometric terms", "MoreExamplesSection"],

Cell["\<\
A hypergeometric term is a sequence composed of factorials, binomials and \
powers.\
\>", "Text",
 CellChangeTimes->{{3.4439760205431385`*^9, 3.4439760484682126`*^9}, {
  3.4439766361437078`*^9, 3.4439766469237223`*^9}, {3.444660313308832*^9, 
  3.444660341821359*^9}}],

Cell[TextData[{
 "The ",
 ButtonBox["DiscreteRatio",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DiscreteRatio"],
 " of a hypergeometric term is a rational function. For example, "
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.444489252971898*^9}, {3.4444982408243065`*^9, 3.4444982413079257`*^9}, {
  3.4446594383605857`*^9, 3.4446594428535585`*^9}, {3.44465948865692*^9, 
  3.444659507752054*^9}, {3.444659657299406*^9, 3.4446596881417923`*^9}, {
  3.4446597430871058`*^9, 3.4446597490465345`*^9}, {3.444660410847582*^9, 
  3.4446604177611284`*^9}, {3.444670887166089*^9, 3.444670981059478*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"t", "(", "k_", ")"}], ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "k"], " ", 
     TemplateBox[{"n","k"},
      "Binomial"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k", "+", "3"}], ")"}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "+", "17"}], ")"}], "!"}]}]]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  TemplateBox[{RowBox[{"f", "(", "k", ")"}],"k"},
   "DiscreteRatio2"], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Factor", "[", 
   TemplateBox[{RowBox[{"t", "(", "k", ")"}],"k"},
    "DiscreteRatio2"], "]"}], TraditionalForm]], "Input"],

Cell["\<\
This ratio is called the certificate for the hypergeometric term.\
\>", "Text",
 CellChangeTimes->{{3.443976787297921*^9, 3.4439768019780855`*^9}}],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Periodic sequences", "MoreExamplesSection"],

Cell[TextData[{
 "Problems involving periodic sequences such as ",
 ButtonBox["Sin ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sin"],
 "and ",
 ButtonBox["Mod",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Mod"],
 " can often be solved very efficiently. "
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.444489252971898*^9}, {3.4444982408243065`*^9, 3.4444982413079257`*^9}, {
  3.4446594383605857`*^9, 3.4446594428535585`*^9}, {3.44465948865692*^9, 
  3.444659507752054*^9}, {3.444659657299406*^9, 3.4446596881417923`*^9}, {
  3.4446710014505167`*^9, 3.44467102338971*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"GraphicsRow", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"DiscretePlot", "[", 
       RowBox[{
        RowBox[{"sin", "(", 
         FractionBox[
          RowBox[{"\[Pi]", " ", "n"}], "6"], ")"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "30"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red"}], "]"}]}], 
        ",", 
        RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], ",", 
      RowBox[{"DiscretePlot", "[", 
       RowBox[{
        TemplateBox[{"n","4"},
         "Mod"], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "20"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red"}], "]"}]}], 
        ",", 
        RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4990908521259975`*^9, 3.4990908776017776`*^9}}],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Special functions", "MoreExamplesSection"],

Cell[TextData[{
 "Special functions such as ",
 ButtonBox["BernoulliB",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BernoulliB"],
 " and ",
 ButtonBox["Zeta",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Zeta"],
 " play an important role in discrete calculus."
}], "Text"],

Cell["\<\
The zeta function is very useful in evaluating infinite series:\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
  3.444489252971898*^9}, {3.4444982408243065`*^9, 3.4444982413079257`*^9}, {
  3.4446594383605857`*^9, 3.4446594428535585`*^9}, {3.44465948865692*^9, 
  3.444659507752054*^9}, {3.4446601610542154`*^9, 3.4446601764520082`*^9}, {
  3.4446710340847797`*^9, 3.4446710343008013`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   FractionBox["1", 
    SuperscriptBox["n", "2"]]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Table", "[", 
   RowBox[{
    TemplateBox[{"s"},
     "Zeta"], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "2", ",", "10"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 "Symbolic Summation with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Scope of Sum", "MoreExamplesSection"],

Cell[TextData[{
 ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"],
 " can compute:"
}], "Text",
 CellChangeTimes->{{3.3691474811256*^9, 3.3691475712205*^9}, {
   3.36914767534684*^9, 3.36914768711261*^9}, {3.36914775209782*^9, 
   3.36914776289483*^9}, {3.36914782145808*^9, 3.36914782187996*^9}, 
   3.36914785930232*^9, {3.3693017674333115`*^9, 3.3693017685896425`*^9}, {
   3.3799476906272397`*^9, 3.3799476913459854`*^9}, {3.3907557717906*^9, 
   3.3907557799625273`*^9}, 3.393348348022973*^9, {3.443467117567151*^9, 
   3.443467118815199*^9}, {3.4447369150924077`*^9, 3.4447369151080084`*^9}}],

Cell[CellGroupData[{

Cell[" A wide variety of  indefinite sums ", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.4434671222473307`*^9, 3.4434671229649587`*^9}}],

Cell["\<\
Definite sums over finite and infinite intervals               \
\>", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.4434671309992676`*^9, 3.443467132855739*^9}}],

Cell["Multiple sums in an arbitrary number of dimensions", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.443467137021099*^9, 3.4434671529025097`*^9}, {
  3.443467199548304*^9, 3.44346721920506*^9}}],

Cell[TextData[{
 "Sums of piecewise functions, ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]]],
 "-functions, etc. "
}], "Item",
 ShowGroupOpener->False]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Indefinite summation ", "MoreExamplesSection"],

Cell["The indefinite sum of a polynomial is a polynomial.", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444575155277478*^9, 3.4445751660106907`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderscriptBox["\[Sum]", "k"], 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     RowBox[{"3", " ", "k"}], "+", "5"}], ")"}]}], TraditionalForm]], "Input"],

Cell["\<\
The difference of the indefinite sum returns the original expression:\
\>", "MathCaption",
 CellChangeTimes->{{3.4337742668119316`*^9, 3.43377427944858*^9}, {
  3.433774353926799*^9, 3.433774364800556*^9}, {3.433774398716696*^9, 
  3.43377440094761*^9}, {3.433807403707303*^9, 3.433807405724964*^9}, {
  3.433809812725713*^9, 3.4338098134132676`*^9}, {3.4445751719077177`*^9, 
  3.44457517952081*^9}, {3.4446613788586817`*^9, 3.4446613811519995`*^9}, {
  3.444671097863157*^9, 3.444671098056176*^9}}],

Cell[BoxData[
 FormBox[
  TemplateBox[{"%","k"},
   "DifferenceDelta2"], TraditionalForm]], "Input"],

Cell[TextData[{
 "The indefinite sum of a rational function is composed of a rational part \
and a transcendental part based on ",
 ButtonBox["PolyGamma",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PolyGamma"],
 " :"
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderscriptBox["\[Sum]", "k"], 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     RowBox[{"6", " ", "k"}], "+", "12"}], 
    RowBox[{
     SuperscriptBox["k", "3"], "+", 
     RowBox[{"7", " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{"12", " ", "k"}]}]]}], TraditionalForm]], "Input"],

Cell["The answer can be verified as before.", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{"Together", "[", 
   TemplateBox[{"%","k"},
    "DifferenceDelta2"], "]"}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finite sums", "MoreExamplesSection"],

Cell["\<\
Zeilberger\[CloseCurlyQuote]s algorithm provides an important method for \
definite hypergeometric sums:\
\>", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "n"], 
   FractionBox[
    RowBox[{
     RowBox[{"k", "!"}], " ", 
     TemplateBox[{"n","k"},
      "Binomial"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k", "+", "n", "+", "1"}], ")"}], "!"}]]}], 
  TraditionalForm]], "Input"],

Cell["\<\
Summation by parts is a very useful technique for problems involving suitable \
pairs of sequences:\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sum]", " ", 
   RowBox[{
    RowBox[{"f", "[", "k", "]"}], " ", 
    RowBox[{"g", "[", "k", "]"}], " ", "\[Delta]k"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "k", "]"}], " ", 
    SubsuperscriptBox["\[CapitalDelta]", "k", 
     RowBox[{"-", "1"}]], 
    RowBox[{"f", "[", "k", "]"}]}], "-", 
   RowBox[{"\[Sum]", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "k"], 
     RowBox[{"g", "[", "k", "]"}], " ", 
     SubscriptBox["E", "k"], 
     SubsuperscriptBox["\[CapitalDelta]", "k", 
      RowBox[{"-", "1"}]], 
     RowBox[{"f", "[", "k", "]"}], " ", "\[Delta]k"}]}]}]}]], "Text",
 CellChangeTimes->{{3.43380744755081*^9, 3.4338074623294926`*^9}},
 TextAlignment->-0.5,
 FontSize->18,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
We use this idea to compute sums involving special functions, such as the \
following:\
\>", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "m"], 
   FractionBox[
    TemplateBox[{"k"},
     "PolyGamma"], "k"]}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Summation over infinite intervals", "MoreExamplesSection"],

Cell[TextData[{
 "Infinite series of hypergeometric terms are summed by conversion to ",
 ButtonBox["HypergeometricPFQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HypergeometricPFQ"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444575155277478*^9, 3.4445751660106907`*^9}, {3.4445756847418547`*^9, 
   3.4445757870037875`*^9}, {3.4445759906569276`*^9, 3.444576070625603*^9}, {
   3.4445761405474925`*^9, 3.444576146881336*^9}, {3.444671162555625*^9, 
   3.444671162557626*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "n"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "11"], ")"}], 
      RowBox[{"n", "+", "1"}]], " ", 
     TemplateBox[{RowBox[{"2", " ", "n"}],"n"},
      "Binomial"]}], 
    RowBox[{"n", "+", "3"}]]}], TraditionalForm]], "Input"],

Cell["\<\
Euler sums such as the following are evaluated using the residue calculus:\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444575155277478*^9, 3.4445751660106907`*^9}, {3.4445756847418547`*^9, 
   3.4445757870037875`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "\[Infinity]"], 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      TemplateBox[{"k"},
       "HarmonicNumber"], ")"}], "2"], 
    SuperscriptBox["k", "2"]]}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple summation", "MoreExamplesSection"],

Cell[TextData[{
 "The following double sum is evaluated by analyzing the behavior of ",
 ButtonBox["Max",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Max"],
 " for a fixed ",
 StyleBox["i ",
  FontSlant->"Italic"],
 "and variable",
 StyleBox[" j",
  FontSlant->"Italic"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444575155277478*^9, 3.4445751660106907`*^9}, {3.4445756847418547`*^9, 
   3.4445757320740747`*^9}, {3.4446711979711666`*^9, 3.4446711979731665`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "\[Infinity]"], 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"j", "=", "1"}], "\[Infinity]"], 
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"max", "(", 
       RowBox[{"i", ",", "j"}], ")"}], "3"]]}]}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Convergent and Divergent Series", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Patterns of convergence", "MoreExamplesSection"],

Cell["\<\
The sequence of partial sums can be used to determine the convergence or \
divergence of an infinite series.\
\>", "Text",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444587274316187*^9, 3.444587309684108*^9}, {3.4445873603100014`*^9, 
   3.4445874069107857`*^9}}],

Cell[TextData[{
 StyleBox["Example 1",
  FontWeight->"Bold"],
 ": The following series is convergent."
}], "MathCaption",
 CellChangeTimes->{{3.444587410233842*^9, 3.4445874169423575`*^9}, {
  3.4445875449951706`*^9, 3.444587564574175*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"DiscretePlot", "[", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "m"], 
     FractionBox["1", 
      SuperscriptBox["n", "2"]]}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "25"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red"}], "]"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4450091899686747`*^9, 3.4450091901870985`*^9}, {
  3.499090931065034*^9, 3.4990909386469254`*^9}}],

Cell[TextData[{
 StyleBox["Example 2",
  FontWeight->"Bold"],
 ": The sum of all natural numbers is clearly divergent."
}], "MathCaption",
 CellChangeTimes->{{3.444587410233842*^9, 3.4445874397513123`*^9}, {
  3.4445875791141205`*^9, 3.4445875998943863`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"DiscretePlot", "[", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "m"], "n"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "20"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red"}], "]"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.445009192652167*^9, 3.4450091927769804`*^9}, {
  3.499090941470634*^9, 3.4990909483816996`*^9}}],

Cell[TextData[{
 StyleBox["Example 3",
  FontWeight->"Bold"],
 ": The geometric series converges only if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    TemplateBox[{"x"},
     "Abs"], "<", "1"}], TraditionalForm]]],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.444587410233842*^9, 3.4445874397513123`*^9}, {
  3.4445875268358393`*^9, 3.4445875378344035`*^9}, {3.444587608630834*^9, 
  3.444587650830998*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Row", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"DiscretePlot", "[", 
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "1"}], "m"], 
        SuperscriptBox["x", "n"]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "15"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red"}], "]"}]}], 
       ",", 
       RowBox[{"Background", "\[Rule]", "Yellow"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", " ", "300"}], ",", " ", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"Framed", "[", 
           RowBox[{"\"\<x = \>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"TraditionalForm", "[", "x", "]"}], "]"}]}], "]"}], ",", 
          "16", ",", "Blue", ",", 
          RowBox[{"Background", "\[Rule]", 
           RowBox[{"Lighter", "[", "Orange", "]"}]}]}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "3"], ",", "1", ",", 
         FractionBox["4", "3"]}], "}"}]}], "}"}]}], "]"}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.445009195928524*^9, 3.445009196037736*^9}, {
  3.4990909515954237`*^9, 3.4990909606593723`*^9}}],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["The SumConvergence function", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
  3.4316965026739655`*^9, 3.4316965060436945`*^9}, {3.431696571127267*^9, 
  3.4316965737949696`*^9}, {3.4316967704362707`*^9, 3.431696775210054*^9}, {
  3.431697030404669*^9, 3.431697040623062*^9}, {3.4419917236593723`*^9, 
  3.4419917302990365`*^9}, {3.4435360554990683`*^9, 3.443536089648782*^9}, {
  3.443536134250897*^9, 3.4435361472461967`*^9}}],

Cell[TextData[{
 ButtonBox["SumConvergence ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SumConvergence"],
 "returns ",
 ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"],
 ", ",
 ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"],
 ", or a condition on the parameters for the examples given above."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{"SumConvergence", "[", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["n", "2"]], ",", "n"}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"SumConvergence", "[", 
   RowBox[{"n", ",", "n"}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"SumConvergence", "[", 
   RowBox[{
    SuperscriptBox["x", "n"], ",", "n"}], "]"}], TraditionalForm]], "Input"],

Cell["\<\
Special methods are implemented for series of periodic and piecewise \
functions.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444587274316187*^9, 3.444587309684108*^9}, {3.4445873603100014`*^9, 
   3.4445874069107857`*^9}, {3.4445880236989455`*^9, 3.44458805299706*^9}, {
   3.444588091265463*^9, 3.4445881337926984`*^9}, {3.444588175555505*^9, 
   3.444588225773836*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"SumConvergence", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      TemplateBox[{"n","5"},
       "Mod"], " ", 
      RowBox[{"sin", "(", 
       RowBox[{"4", " ", "n"}], ")"}]}], "n"], ",", "n"}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"DiscretePlot", "[", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "m"], 
     RowBox[{"n", " ", 
      RowBox[{"Boole", "[", 
       RowBox[{
        SuperscriptBox["n", "2"], "<", "1000"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", "80", ",", "2"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", "Red"}], "]"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4450092052115355`*^9, 3.4450092054299593`*^9}, {
  3.4990909789588757`*^9, 3.499090985791939*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"SumConvergence", "[", 
   RowBox[{
    RowBox[{"n", " ", 
     RowBox[{"Boole", "[", 
      RowBox[{
       SuperscriptBox["n", "2"], "<", "1000"}], "]"}]}], ",", "n"}], "]"}], 
  TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Divergent series", "MoreExamplesSection"],

Cell["Here is a divergent alternating series.", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444587274316187*^9, 3.444587309684108*^9}, {3.4445873603100014`*^9, 
   3.4445874069107857`*^9}, {3.4445880236989455`*^9, 3.44458805299706*^9}, {
   3.444588091265463*^9, 3.4445881337926984`*^9}, {3.444588175555505*^9, 
   3.444588225773836*^9}, {3.444588262622453*^9, 3.4445882723884287`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "\[Infinity]"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"]}], TraditionalForm]], "Input"],

Cell["\<\
We can use Abel regularization to assign a value to this series:\
\>", "MathCaption",
 CellChangeTimes->{{3.433775779728037*^9, 3.4337758341748285`*^9}, {
  3.433807577503661*^9, 3.433807579638832*^9}, {3.444661620670246*^9, 
  3.444661622838743*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", 
    SuperscriptBox["x", "n"]}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderscriptBox["lim", 
    RowBox[{"x", "\[Rule]", "1"}]], "\[ThinSpace]", "%"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Sum", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
    RowBox[{"Regularization", "\[Rule]", "\"\<Abel\>\""}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Solutions of Difference Equations", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Scope of RSolve and RecurrenceTable", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
  3.4316965026739655`*^9, 3.4316965060436945`*^9}, {3.431696571127267*^9, 
  3.4316965737949696`*^9}, {3.431696998641847*^9, 3.4316970269881372`*^9}, {
  3.443536066263482*^9, 3.4435360744069953`*^9}, {3.4435361201947565`*^9, 
  3.443536130147939*^9}, {3.443536702594185*^9, 3.4435367078671875`*^9}, {
  3.444059467197205*^9, 3.444059481703106*^9}, {3.4440596667881384`*^9, 
  3.444059676212081*^9}}],

Cell[TextData[{
 ButtonBox["RSolve ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"],
 "and ",
 ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"],
 " can handle the following types of equations:"
}], "Text",
 CellChangeTimes->{{3.3691474811256*^9, 3.3691475712205*^9}, {
   3.36914767534684*^9, 3.36914768711261*^9}, {3.36914775209782*^9, 
   3.36914776289483*^9}, {3.36914782145808*^9, 3.36914782187996*^9}, 
   3.36914785930232*^9, {3.3693017674333115`*^9, 3.3693017685896425`*^9}, {
   3.3799476906272397`*^9, 3.3799476913459854`*^9}, {3.3907557717906*^9, 
   3.3907557799625273`*^9}, 3.393348348022973*^9, {3.444503989980796*^9, 
   3.4445039974137263`*^9}, {3.444671447110078*^9, 3.4446714676881356`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Ordinary difference equations (linear, nonlinear, single, system) \
\>", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.4445040005836525`*^9, 3.4445040107336626`*^9}}],

Cell["\<\
A limited class of linear and nonlinear partial difference equations \
\>", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.444504013903589*^9, 3.4445040605467887`*^9}, {
   3.4446713712994976`*^9, 3.444671372634631*^9}, 3.4447373573805003`*^9}],

Cell["\<\
Difference-algebraic equations (linear constant coefficient systems)\
\>", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.4445040350156097`*^9, 3.4445040371861506`*^9}}]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Approximation of square roots", "MoreExamplesSection"],

Cell["\<\
The difference equation for the approximation of square roots has a closed \
form solution.\
\>", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{"Quiet", "[", 
   RowBox[{"RSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "(", 
         RowBox[{"n", "+", "1"}], ")"}], "\[LongEqual]", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"y", "(", "n", ")"}], "+", 
           FractionBox["a", 
            RowBox[{"y", "(", "n", ")"}]]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"y", "(", "0", ")"}], "\[LongEqual]", 
        FractionBox["1", "m"]}]}], "}"}], ",", "y", ",", "n"}], "]"}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Chop", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "(", "13", ")"}], "/.", "\[InvisibleSpace]", 
       RowBox[{"%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
      "/.", "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"m", "\[Rule]", 
        FractionBox["1", "7"]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "1.", ",", "8"}], "}"}]}], "]"}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.445010795871952*^9, 3.4450107974632034`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"N", "[", 
   RowBox[{"Chop", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      SqrtBox["a"], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "1.", ",", "8"}], "}"}]}], "]"}], "]"}], "]"}], 
  TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Cliff random number generator", "MoreExamplesSection",
 CellChangeTimes->{{3.44500922930056*^9, 3.4450092420159454`*^9}}],

Cell["Generate a list of random numbers and plot the results.", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.4445047643785334`*^9, 3.4445047812450523`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"RecurrenceTable", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "(", 
          RowBox[{"n", "+", "1"}], ")"}], "\[LongEqual]", 
         TemplateBox[{TemplateBox[{
             RowBox[{"(", 
               RowBox[{"100", " ", 
                 RowBox[{"log", "(", 
                   RowBox[{"x", "(", "n", ")"}], ")"}]}], ")"}], "1"}, "Mod"]},
          "Abs"]}], ",", 
        RowBox[{
         RowBox[{"x", "(", "0", ")"}], "\[LongEqual]", "0.1"}]}], "}"}], ",", 
      "x", ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", 
        SuperscriptBox["10", "4"]}], "}"}]}], "]"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.0007", "]"}], ",", "Blue"}], "]"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.499091012250556*^9, 3.4990910203628683`*^9}, 
   3.4990926502019625`*^9}],

Cell["\<\
Study the statistical properties of this set of random numbers.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.4445047643785334`*^9, 3.4445047812450523`*^9}, {3.444504831080076*^9, 
   3.4445048607252064`*^9}, {3.444661786435154*^9, 3.444661813049802*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Timing", "[", 
   RowBox[{
    RowBox[{"t", "=", 
     RowBox[{"RecurrenceTable", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "(", 
           RowBox[{"n", "+", "1"}], ")"}], "\[LongEqual]", 
          TemplateBox[{TemplateBox[{
              RowBox[{"(", 
                RowBox[{"100", " ", 
                  RowBox[{"log", "(", 
                    RowBox[{"x", "(", "n", ")"}], ")"}]}], ")"}], "1"}, 
             "Mod"]},
           "Abs"]}], ",", 
         RowBox[{
          RowBox[{"x", "(", "0", ")"}], "\[LongEqual]", "0.1"}]}], "}"}], ",",
        "x", ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         SuperscriptBox["10", "5"]}], "}"}]}], "]"}]}], ";"}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4990926418712425`*^9, 3.49909264258887*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Mean", "[", "t", "]"}], ",", 
    RowBox[{"Median", "[", "t", "]"}]}], "}"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"ListPlot", "[", 
   RowBox[{
    TemplateBox[{RowBox[{"{", 
        RowBox[{
          RowBox[{"Range", "[", 
            RowBox[{".05", ",", ".95", ",", ".1"}], "]"}], ",", 
          RowBox[{"BinCounts", "[", 
            RowBox[{"t", ",", 
              RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", ".1"}], "}"}]}], "]"}]}], "}"}]},
     "Transpose"], ",", 
    RowBox[{"Filling", "\[Rule]", "0"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FillingStyle", "\[Rule]", "Blue"}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Douady\[CloseCurlyQuote]s Rabbit Fractal", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Complex dynamical systems", "MoreExamplesSection"],

Cell["Let c be a fixed complex number (say c = 0.1 + 3 I).", "Text",
 CellChangeTimes->{{3.443895315977474*^9, 3.4438953409384336`*^9}}],

Cell["Consider the quadratic recurrence equation ", "Text",
 CellChangeTimes->{{3.4438953496903706`*^9, 3.44389536371531*^9}, {
  3.4441399133512435`*^9, 3.4441399270485706`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["z", 
    RowBox[{"n", "+", "1"}]], "=", 
   RowBox[{
    SubsuperscriptBox["z", "n", "2"], "+", "c"}]}], 
  TraditionalForm]], "DisplayFormula",
 FontSize->24],

Cell[TextData[{
 "for a fixed ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "0"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.443895499861746*^9, 3.4438955264451685`*^9}}],

Cell["\<\
Iterated maps of this type were studied by Pierre Fatou and Gaston Julia at \
the start of the twentieth century.\
\>", "Text",
 CellChangeTimes->{{3.443895530329718*^9, 3.4438955467259483`*^9}, {
  3.4438955978921385`*^9, 3.443895622026266*^9}, {3.444582968948637*^9, 
  3.4445829710859194`*^9}}],

Cell[TextData[{
 "The global behavior of this map for all values of ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 " was studied by Beno\[IHat]t Mandelbrot in the 1970s."
}], "Text"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting the rabbit fractal", "MoreExamplesSection"],

Cell[TextData[{
 "The special case  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{
     RowBox[{"-", "0.122561"}], "+", 
     RowBox[{"0.744862", " ", "\[ImaginaryI]"}]}]}], TraditionalForm]]],
 " gives rise to Douady\[CloseCurlyQuote]s rabbit fractal."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"c", "=", 
    RowBox[{
     RowBox[{"-", "0.122561"}], "+", 
     RowBox[{"0.744862", " ", "\[ImaginaryI]"}]}]}], ";"}], 
  TraditionalForm]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellID->355890892],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"zinit", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"a", "+", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "1.3"}], ",", "1.3", ",", 
        FractionBox["2.6", "149"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", 
        RowBox[{"-", "1.3"}], ",", "1.3", ",", 
        FractionBox["2.6", "149"]}], "}"}]}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"iterates", "=", 
    RowBox[{"RecurrenceTable", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"z", "(", 
          RowBox[{"k", "+", "1"}], ")"}], "\[LongEqual]", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"z", "(", "k", ")"}], "2"], "+", "c"}]}], ",", 
        RowBox[{
         RowBox[{"z", "(", "0", ")"}], "\[LongEqual]", "zinit"}]}], "}"}], 
      ",", "z", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"max", "(", 
           TemplateBox[{"#1"},
            "Abs"], ")"}], "\[LessEqual]", "1"}], ",", "1", ",", 
         RowBox[{
          RowBox[{"max", "(", 
           TemplateBox[{"#1"},
            "Abs"], ")"}], "\[LessEqual]", "1.25"}], ",", 
         FractionBox["1", "5"], ",", 
         RowBox[{
          RowBox[{"max", "(", 
           TemplateBox[{"#1"},
            "Abs"], ")"}], "\[LessEqual]", "1.5"}], ",", 
         FractionBox["1", "7"], ",", "True", ",", "0"}], "]"}], "&"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"iterates", ",", 
        RowBox[{"(", "\[NoBreak]", GridBox[{
           {"2"},
           {"3"},
           {"1"}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.7]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], 
       "]"}], ",", 
      RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], TraditionalForm]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],

Cell[BoxData[
 FormBox[
  RowBox[{"ArrayPlot", "[", 
   RowBox[{
    TemplateBox[{RowBox[{"Reverse", "[", "data", "]"}]},
     "Transpose"], ",", 
    RowBox[{"ColorRules", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "Green"}], ",", 
       RowBox[{
        FractionBox["1", "5"], "\[Rule]", "Blue"}], ",", 
       RowBox[{"0", "\[Rule]", "Yellow"}], ",", 
       RowBox[{
        FractionBox["1", "7"], "\[Rule]", "Red"}]}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "350"}], ",", 
    RowBox[{"Frame", "\[Rule]", "None"}]}], "]"}], TraditionalForm]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Sequence Recognition", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Finding the general term of a sequence", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
  3.4316965026739655`*^9, 3.4316965060436945`*^9}, {3.431696571127267*^9, 
  3.4316965737949696`*^9}, {3.431696998641847*^9, 3.4316970269881372`*^9}, {
  3.431799845702305*^9, 3.4317998526125813`*^9}, {3.431882693811874*^9, 
  3.4318826975571737`*^9}, {3.443375406214078*^9, 3.4433754169473596`*^9}}],

Cell[TextData[{
 ButtonBox["FindSequenceFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindSequenceFunction"],
 " can be used to find a closed-form expression for a finite sequence."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{"FindSequenceFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "4", ",", "9", ",", "16", ",", "25", ",", "36", ",", "49", ",",
       "64", ",", "81", ",", "100"}], "}"}], ",", "n"}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"FindSequenceFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", 
      "21", ",", "34", ",", "55"}], "}"}], ",", "n"}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"FindSequenceFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "3", ",", "4", ",", "7", ",", "11", ",", "18", ",", "29", ",", 
      "47"}], "}"}], ",", "n"}], "]"}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["The generating function for a sequence", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
  3.4316965026739655`*^9, 3.4316965060436945`*^9}, {3.431696571127267*^9, 
  3.4316965737949696`*^9}, {3.431696998641847*^9, 3.4316970269881372`*^9}, {
  3.431799845702305*^9, 3.4317998526125813`*^9}, {3.431882693811874*^9, 
  3.4318826975571737`*^9}, {3.443375406214078*^9, 3.4433754352157793`*^9}}],

Cell["\<\
The generating function for the Lucas numbers is a rational function.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444583069260495*^9, 3.444583109088827*^9}, {3.44458619187409*^9, 
   3.444586222919284*^9}, {3.4445862535432615`*^9, 3.4445862537148685`*^9}, {
   3.444586291628394*^9, 3.4445863123615913`*^9}, {3.4445864673535523`*^9, 
   3.444586484873026*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"FindGeneratingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "3", ",", "4", ",", "7", ",", "11", ",", "18", ",", "29", ",", 
      "47"}], "}"}], ",", "x"}], "]"}], TraditionalForm]], "Input",
 CellID->181474481],

Cell[BoxData[
 FormBox[
  RowBox[{"Series", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "7"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellID->118063561],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier coefficients for a square wave", "MoreExamplesSection"],

Cell["\<\
We begin by constructing a square wave with period 2 \[Pi].\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444583069260495*^9, 3.444583109088827*^9}, {3.44458619187409*^9, 
   3.444586222919284*^9}, {3.4445862535432615`*^9, 3.4445862537148685`*^9}, {
   3.444586291628394*^9, 3.4445863123615913`*^9}, {3.4445864673535523`*^9, 
   3.444586484873026*^9}, {3.4445868428139114`*^9, 3.444586872073287*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"SquareWave", "[", 
     FractionBox["x", 
      RowBox[{"2", " ", "\[Pi]"}]], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[Pi]"}], ",", 
      RowBox[{"3", " ", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"Exclusions", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.008", "]"}], ",", "Red"}], "}"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4990910581787224`*^9, 3.4990910669150586`*^9}, {
  3.499092682011586*^9, 3.4990926855529222`*^9}}],

Cell["\<\
The Fourier sine expansion can be calculated by extrapolation as follows.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444583069260495*^9, 3.444583109088827*^9}, {3.44458619187409*^9, 
   3.444586222919284*^9}, {3.4445862535432615`*^9, 3.4445862537148685`*^9}, {
   3.444586291628394*^9, 3.4445863123615913`*^9}, {3.4445864673535523`*^9, 
   3.444586484873026*^9}, {3.4445868428139114`*^9, 3.4445869288967175`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"t1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"FourierSinCoefficient", "[", 
      RowBox[{
       RowBox[{"SquareWave", "[", 
        FractionBox["x", 
         RowBox[{"2", " ", "\[Pi]"}]], "]"}], ",", "x", ",", "n"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "8"}], "}"}]}], "]"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"FindSequenceFunction", "[", 
   RowBox[{"t1", ",", "n"}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "1"}], "12"], 
   RowBox[{"%", " ", 
    RowBox[{"sin", "(", 
     RowBox[{"n", " ", "x"}], ")"}]}]}], TraditionalForm]], "Input"],

Cell[TextData[{
 "The result agrees with the answer from ",
 ButtonBox["FourierSinSeries",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FourierSinSeries"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444583069260495*^9, 3.444583109088827*^9}, {3.44458619187409*^9, 
   3.444586222919284*^9}, {3.4445862535432615`*^9, 3.4445862537148685`*^9}, {
   3.444586291628394*^9, 3.4445863123615913`*^9}, {3.4445864673535523`*^9, 
   3.444586484873026*^9}, {3.4445868428139114`*^9, 3.4445869288967175`*^9}, {
   3.4445869607876143`*^9, 3.444586978792553*^9}, {3.444671583402706*^9, 
   3.444671583404706*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"FourierSinSeries", "[", 
   RowBox[{
    RowBox[{"SquareWave", "[", 
     FractionBox["x", 
      RowBox[{"2", " ", "\[Pi]"}]], "]"}], ",", "x", ",", "12"}], "]"}], 
  TraditionalForm]], "Input"],

Cell["\<\
A plot of the Fourier sine series and the original function shows the quality \
of the approximation.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444583069260495*^9, 3.444583109088827*^9}, {3.44458619187409*^9, 
   3.444586222919284*^9}, {3.4445862535432615`*^9, 3.4445862537148685`*^9}, {
   3.444586291628394*^9, 3.4445863123615913`*^9}, {3.4445864673535523`*^9, 
   3.444586484873026*^9}, {3.444586801491872*^9, 3.4445868282076316`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SquareWave", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", "\[Pi]"}]], "]"}], ",", "%"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[Pi]"}], ",", 
      RowBox[{"3", " ", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"Exclusions", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.007", "]"}], ",", " ", "Red"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.007", "]"}], ",", " ", "Blue"}], 
        "}"}]}], "}"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "Yellow"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4990911066185856`*^9, 3.499091113982069*^9}, {
  3.499092690841526*^9, 3.4990926952564955`*^9}}],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["The Efficiency of Grade-School Multiplication", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Grade-school multiplication", "MoreExamplesSection"],

Cell["\<\
Consider multiplying two 2-digit numbers:
\
\>", "Text",
 CellChangeTimes->{3.444661971271087*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{GridBox[{
     {"x", "=", 
      RowBox[{
       SubscriptBox["x", "1"], "\[Beta]"}], "+", 
      SubscriptBox["x", "0"]},
     {"y", "=", 
      RowBox[{
       SubscriptBox["y", "1"], "\[Beta]"}], "+", 
      SubscriptBox["y", "0"]}
    }], "\[IndentingNewLine]"}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{3.444671603230688*^9},
 TextAlignment->-0.5],

Cell["\<\
The schoolbook product is:
\
\>", "Text",
 CellChangeTimes->{{3.444655538984639*^9, 3.444655541839549*^9}, 
   3.4446619780729485`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"x", " ", "y"}], " ", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["y", "1"]}], ")"}], " ", 
      SuperscriptBox["\[Beta]", "2"]}], " ", "+", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["x", "0"], " ", 
         SubscriptBox["y", "1"]}], " ", "+", " ", 
        RowBox[{
         SubscriptBox["x", "1"], " ", 
         SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Beta]"}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["x", "0"], " ", 
      SubscriptBox["y", "0"]}]}]}], "\[IndentingNewLine]"}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{3.4446715927346387`*^9},
 TextAlignment->-0.5],

Cell["\<\
The operation count of multiplication using the schoolbook method is:
\
\>", "Text",
 CellChangeTimes->{3.4446619820979033`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"M", "(", "n", ")"}], " ", "=", " ", 
   RowBox[{"O", "(", 
    SuperscriptBox["n", "2"], ")"}]}], TraditionalForm]], "DisplayFormula",
 TextAlignment->-0.5]
}, Closed]],

Cell[CellGroupData[{

Cell["The Karatsuba method ", "MoreExamplesSection"],

Cell["\<\
A divide and conquer scheme for multiplication was given by Karatsuba in the \
early 1960s.\
\>", "Text",
 CellChangeTimes->{{3.4960659089800715`*^9, 3.4960659202593775`*^9}}],

Cell["\<\
The method involves three multiplications and some additions, instead of four \
multiplications.
\
\>", "Text",
 CellChangeTimes->{{3.444654129975269*^9, 3.444654149226409*^9}, {
  3.444662013657917*^9, 3.4446620479948378`*^9}, {3.4446620798356624`*^9, 
  3.444662088696803*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"x", " ", "y"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], 
      SubscriptBox["y", "1"], 
      SuperscriptBox["\[Beta]", "2"]}], " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "1"], "+", 
           SubscriptBox["x", "0"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["y", "1"], "+", 
           SubscriptBox["y", "0"]}], ")"}]}], " ", "-", " ", 
        RowBox[{
         SubscriptBox["x", "1"], " ", 
         SubscriptBox["y", "1"]}], " ", "-", " ", 
        RowBox[{
         SubscriptBox["x", "0"], " ", 
         SubscriptBox["y", "0"]}]}], ")"}], "\[Beta]"}], "+", " ", 
     RowBox[{
      SubscriptBox["x", "0"], "  ", 
      SubscriptBox["y", "0"]}]}]}], "\[IndentingNewLine]"}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{3.444662096621908*^9},
 TextAlignment->-0.5]
}, Closed]],

Cell[CellGroupData[{

Cell["Complexity of Karatsuba multiplication", "MoreExamplesSection"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]]],
 "-difference equation for the Karatsuba method is:"
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{"rsol", "=", 
   RowBox[{"RSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "(", "n", ")"}], "\[LongEqual]", 
        RowBox[{"3", " ", 
         RowBox[{"M", "(", 
          FractionBox["n", "2"], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"M", "(", "1", ")"}], "\[LongEqual]", "1"}]}], "}"}], ",", 
     RowBox[{"M", "(", "n", ")"}], ",", "n"}], "]"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"M", "(", "n", ")"}], "/.", "\[InvisibleSpace]", 
      RowBox[{"First", "[", "rsol", "]"}]}], ")"}], "-", 
    SuperscriptBox["n", 
     RowBox[{
      SubscriptBox["log", "2"], "(", "3", ")"}]]}], "]"}], 
  TraditionalForm]], "Input"],

Cell["Hence the complexity of this scheme is given by:", "MathCaption",
 CellChangeTimes->{{3.444654577582765*^9, 3.4446546184251356`*^9}}],

Cell[BoxData[
 FormBox[
  SuperscriptBox["n", 
   RowBox[{
    SubscriptBox["log", "2."], "(", "3", ")"}]], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["A comparison of the schoolbook and Karatsuba methods", \
"MoreExamplesSection"],

Cell["\<\
The following fractal graphic illustrates the advantage of the Karatsuba \
method for multiplying large numbers.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
   3.444484986113626*^9, 3.4444850032898865`*^9}, {3.444489246107634*^9, 
   3.444489252971898*^9}, {3.444489590225669*^9, 3.444489592581359*^9}, 
   3.444504175491748*^9, {3.4445042482440577`*^9, 3.444504272104868*^9}, {
   3.444583069260495*^9, 3.444583109088827*^9}, {3.44458619187409*^9, 
   3.444586222919284*^9}, {3.4445862535432615`*^9, 3.4445862537148685`*^9}, {
   3.444586291628394*^9, 3.4445863123615913`*^9}, {3.4445864673535523`*^9, 
   3.444586484873026*^9}, {3.4446549975658164`*^9, 3.444655080763816*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"KaratsubaGasket", "[", "n_", "]"}], ":=", 
   RowBox[{
    RowBox[{"ksg", "[", "n", "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.", ",", "0."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.", ",", "1."}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ksg", "[", "0", "]"}], "[", 
    RowBox[{"c1_", ",", "c2_"}], "]"}], ":=", 
   RowBox[{"Polygon", "[", 
    RowBox[{"{", 
     RowBox[{"c1", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", 
        RowBox[{
        "c2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "}"}],
       ",", "c2", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", 
        RowBox[{
        "c1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
       "}"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ksg", "[", "n_", "]"}], "[", 
    RowBox[{"c1_", ",", "c2_"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mid", "=", 
       RowBox[{"0.5", " ", 
        RowBox[{"(", 
         RowBox[{"c1", "+", "c2"}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"ksg", "[", 
         RowBox[{"n", "-", "1"}], "]"}], "[", 
        RowBox[{"c1", ",", "mid"}], "]"}], ",", 
       RowBox[{
        RowBox[{"ksg", "[", 
         RowBox[{"n", "-", "1"}], "]"}], "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
           "c2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          "}"}], ",", "mid"}], "]"}], ",", 
       RowBox[{
        RowBox[{"ksg", "[", 
         RowBox[{"n", "-", "1"}], "]"}], "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
           "c1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          "}"}], ",", "mid"}], "]"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Orange", ",", 
      RowBox[{"KaratsubaGasket", "[", "j", "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "0", ",", "7", ",", "1"}], "}"}], ",", 
   RowBox[{"AnimationRepetitions", "\[Rule]", "1"}], ",", 
   RowBox[{"DefaultDuration", "\[Rule]", "10"}]}], "]"}]}], "Input"],

Cell["\<\
In practice, it is more efficient to use schoolbook multiplication for \
numbers with around 100 decimal digits or less.\
\>", "Text",
 CellChangeTimes->{{3.444655477533876*^9, 3.4446555203887243`*^9}, {
  3.444656832183505*^9, 3.4446568567076483`*^9}}],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["The Evaluation of Sums", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Techniques of summation", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
  3.4316965026739655`*^9, 3.4316965060436945`*^9}, {3.431696571127267*^9, 
  3.4316965737949696`*^9}, {3.431696998641847*^9, 3.4316970269881372`*^9}, {
  3.431799845702305*^9, 3.4317998526125813`*^9}, {3.431882693811874*^9, 
  3.4318826975571737`*^9}, {3.444486974664628*^9, 3.4444869762714896`*^9}}],

Cell["The following techniques are used for summation:", "Text"],

Cell[CellGroupData[{

Cell["\<\
Algorithms for basic classes such as polynomial, rational, hypergeometric \
term, polygamma sums, etc.\
\>", "Item",
 ShowGroupOpener->False],

Cell["\<\
Special methods for divergent sums, piecewise sums, holonomic sums, etc.\
\>", "Item",
 ShowGroupOpener->False],

Cell["\<\
Table lookup for basic examples and for sums from standard references.\
\>", "Item",
 ShowGroupOpener->False]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Architecture of Sum", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
   3.4316965026739655`*^9, 3.4316965060436945`*^9}, {3.431696571127267*^9, 
   3.4316965737949696`*^9}, {3.4316967704362707`*^9, 3.431696775210054*^9}, {
   3.431697030404669*^9, 3.431697040623062*^9}, {3.4317998561577234`*^9, 
   3.431799872373372*^9}, {3.4318827026925845`*^9, 3.431882709630639*^9}, {
   3.4437876396483483`*^9, 3.4437876471678376`*^9}, 3.4444847599205265`*^9, {
   3.444484860091979*^9, 3.4444848656769943`*^9}, {3.4444851832740088`*^9, 
   3.4444851898886633`*^9}}],

Cell["\<\
Each class of sums is evaluated using a specific internal function, as shown \
in the examples given below.\
\>", "Text",
 CellChangeTimes->{{3.444484873399291*^9, 3.4444849127440042`*^9}, {
  3.444487435442268*^9, 3.4444874434921775`*^9}}],

Cell["\<\
The following indefinite sum is evaluated using the algorithm for rational \
summation.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderscriptBox["\[Sum]", "k"], 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     RowBox[{"2", " ", "k"}], "+", "2"}], 
    RowBox[{
     SuperscriptBox["k", "3"], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{"2", " ", "k"}]}]]}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"Sum`SumRationalFunction", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     RowBox[{"2", " ", "k"}], "+", "2"}], 
    RowBox[{
     SuperscriptBox["k", "3"], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{"2", " ", "k"}]}]], ",", "k"}], "]"}]], "Input"],

Cell["\<\
This finite hypergeometric sum is evaluated using \
Zeilberger\[CloseCurlyQuote]s algorithm.\
\>", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "0"}], 
    RowBox[{"2", " ", "n"}]], 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "i"], " ", 
     SuperscriptBox[
      TemplateBox[{RowBox[{"2", " ", "n"}],"i"},
       "Binomial"], "2"]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     TemplateBox[{RowBox[{"2", " ", "n"}],"n"},
      "Binomial"]}]]}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"Sum`SumZeilberger", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "i"], " ", 
     SuperscriptBox[
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"2", " ", "n"}], ",", "i"}], "]"}], "2"]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"2", " ", "n"}], ",", "n"}], "]"}]}]], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "0", ",", 
     RowBox[{"2", " ", "n"}]}], "}"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Method option", "MoreExamplesSection",
 CellChangeTimes->{{3.4316963186960897`*^9, 3.4316963548270793`*^9}, {
   3.4316965026739655`*^9, 3.4316965060436945`*^9}, {3.431696571127267*^9, 
   3.4316965737949696`*^9}, {3.4316967704362707`*^9, 
   3.4316967891881914`*^9}, {3.4316970441019955`*^9, 3.431697049234593*^9}, {
   3.431799877383572*^9, 3.431799880911213*^9}, 3.443787279197399*^9}],

Cell[TextData[{
 "The ",
 ButtonBox["Method",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Method"],
 " option makes it possible to access specific algorithms for ",
 ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"],
 "."
}], "Text"],

Cell[TextData[{
 "Also, ",
 ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"],
 " can be extended with any user-defined method."
}], "Text"],

Cell["\<\
The following function can be used to find the sum of the squares of integers \
for a given range.\
\>", "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.4444868201250844`*^9, 
  3.444486835023657*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SumSquares", "[", 
    RowBox[{"expr_", ",", 
     RowBox[{"{", 
      RowBox[{"k_", ",", "min_", ",", "max_"}], "}"}]}], "]"}], "/;", 
   RowBox[{
    RowBox[{"IntegerQ", "[", "min", "]"}], "&&", 
    RowBox[{"IntegerQ", "[", "max", "]"}], "&&", 
    RowBox[{"max", ">", "min"}]}]}], ":=", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "min"}], "max"], 
   SuperscriptBox["expr", "2"]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SumSquares", "[", "___", "]"}], ":=", "$Failed"}]], "Input"],

Cell[TextData[{
 "The ",
 ButtonBox["Method",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Method"],
 " option allows this function to be called from within ",
 ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4444849229467964`*^9, 3.4444849465349035`*^9}, {
  3.444484986113626*^9, 3.4444850032898865`*^9}, {3.4444868201250844`*^9, 
  3.4444868747271843`*^9}, {3.4447386006641207`*^9, 3.444738621163309*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Sum", "[", 
   RowBox[{"k", ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "200"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "SumSquares"}]}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.496065865126504*^9, 3.4960658681062374`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "1"}], "200"], 
   SuperscriptBox["k", "2"]}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["The Internals of RSolve", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Structure of the RSolve code ", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[TextData[{
 "Many important algorithms in ",
 Cell[BoxData[
  ButtonBox["RSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RSolve"]], "InlineFormula"],
 " are written using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " programming language."
}], "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.442331980537386*^9, 3.4423319815826263`*^9}}],

Cell["\<\
The design is modular, with separate functions for solving each subproblem.\
\>", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.36559027870896*^9, 3.36559033796693*^9}, {
   3.36577723192826*^9, 3.36577725758468*^9}, {3.3797055565157194`*^9, 
   3.379705595016951*^9}, {3.3800351224679613`*^9, 3.3800351406562757`*^9}, 
   3.3802984302219934`*^9, 3.393259742336023*^9, 3.393259828618377*^9}],

Cell["\<\
The modular design helps in automatic selection of the best algorithm for \
each problem.\
\>", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.36559027870896*^9, 3.36559033796693*^9}, {
   3.36577723192826*^9, 3.36577725758468*^9}, {3.3797055565157194`*^9, 
   3.379705595016951*^9}, {3.379706390479905*^9, 3.379706432121863*^9}, {
   3.380035163594804*^9, 3.3800352339254427`*^9}, 3.380036211639573*^9, {
   3.380036245515441*^9, 3.380036247093606*^9}, 3.3932597583206024`*^9}],

Cell["\<\
Also, it is easy to add new algorithms whenever they become available.  \
\>", "Item",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.3800363039388113`*^9, 3.380036306438875*^9}, {
   3.3800363969724426`*^9, 3.3800364175510945`*^9}, {3.3802986676233597`*^9, 
   3.3802986775676594`*^9}, 3.393259760851885*^9}]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving a second-order ODE", "MoreExamplesSection"],

Cell["The general solution of ", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"RSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "(", 
       RowBox[{"x", "+", "2"}], ")"}], "-", 
      RowBox[{"5", " ", 
       RowBox[{"y", "(", 
        RowBox[{"x", "+", "1"}], ")"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"y", "(", "x", ")"}]}]}], "\[LongEqual]", 
     RowBox[{"x", "+", "1"}]}], ",", "y", ",", "x"}], "]"}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4450093234235573`*^9, 3.445009328587455*^9}}],

Cell["is found using ", "MathCaption",
 CellChangeTimes->{{3.3800352853802147`*^9, 3.380035287630286*^9}, {
   3.380424024604211*^9, 3.3804240286700573`*^9}, 3.3932597484923515`*^9, 
   3.3932598322902994`*^9}],

Cell[BoxData[
 RowBox[{"RSolve`RSolveLinearHomogeneousWithConstantCoefficients", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", "3", ",", "x"}], 
  "]"}]], "Input"],

Cell["followed by ", "MathCaption",
 CellChangeTimes->{{3.3800352853802147`*^9, 3.380035287630286*^9}, {
   3.3800362621408663`*^9, 3.3800362670784926`*^9}, {3.380298573317755*^9, 
   3.380298575841384*^9}, 3.3932597537111683`*^9, 3.3932598354622145`*^9}],

Cell[BoxData[
 RowBox[{"RSolve`RSolveVariationOfParameters", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["2", "x"], ",", 
     SuperscriptBox["3", "x"]}], "}"}], ",", "2", ",", 
   RowBox[{"x", "+", "1"}], ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"-", "5"}], ",", "1"}], "}"}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Documentation and Project Ideas for Discrete Calculus", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell["Guide page for discrete calculus ", "MoreExamplesSection"],

Cell[CellGroupData[{

Cell["\<\
Around 30 functions (solvers, special functions, utilities, etc.) were \
developed as part of the Discrete Calculus project.\
\>", "Item",
 CellChangeTimes->{{3.442766385140456*^9, 3.442766394734948*^9}, {
   3.4427670326166945`*^9, 3.4427670672660713`*^9}, 3.442858993487951*^9, {
   3.4428590490267987`*^9, 3.442859098060113*^9}}],

Cell["\<\
An internal web page was used to track the progress of the project.\
\>", "Item"],

Cell[TextData[{
 "The ",
 ButtonBox["Discrete Calculus guide page",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/DiscreteCalculus"],
 " is a good place to start understanding the functionality that is available \
in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Item",
 CellChangeTimes->{{3.496066063302196*^9, 3.496066063598609*^9}}]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function pages ", "MoreExamplesSection"],

Cell[TextData[{
 "Every function in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has its own homepage called a function page."
}], "Text"],

Cell["\<\
The function page has the definition of the function, further information \
about it, and a collection of examples on its use.\
\>", "Text"],

Cell[TextData[{
 "Let us look at the ",
 ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"],
 " function page:"
}], "MathCaption",
 CellChangeTimes->{{3.442860409621127*^9, 3.442860412054852*^9}, {
  3.444671836510014*^9, 3.4446718365120144`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"?", "Sum"}], TraditionalForm]], "Input"],

Cell[TextData[{
 "Interesting application examples can also be found on the ",
 ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"],
 " page:"
}], "MathCaption",
 CellChangeTimes->{{3.442860430947421*^9, 3.4428604524297223`*^9}, {
  3.444671858622225*^9, 3.444671858624225*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"?", "RecurrenceTable"}], TraditionalForm]], "Input"],

Cell[TextData[{
 "The method of variation of parameters is coded on the ",
 ButtonBox["Casoratian",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Casoratian"],
 " page:"
}], "MathCaption",
 CellChangeTimes->{{3.442860430947421*^9, 3.4428605002461743`*^9}, 
   3.4443928379016237`*^9, {3.4446718743928022`*^9, 3.4446719031146736`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"?", "Casoratian"}], TraditionalForm]], "Input"],

Cell["", "Spacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Project ideas for discrete calculus", "MoreExamplesSection"],

Cell[TextData[{
 "I encourage you to use the Discrete Calculus functions in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to:"
}], "Text",
 CellChangeTimes->{{3.4960660876080866`*^9, 3.496066117077809*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Prepare a demonstration for using graphical functions such as ",
 ButtonBox["BarChart",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BarChart"],
 " and ",
 ButtonBox["DiscretePlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DiscretePlot"],
 "."
}], "Item",
 CellChangeTimes->{3.496066123240085*^9}],

Cell["\<\
Give a talk or a course on applying discrete calculus to statistics, number \
theory, and other fields.\
\>", "Item",
 CellChangeTimes->{{3.4450121211788497`*^9, 3.445012131303574*^9}, {
  3.4990927514966583`*^9, 3.499092755568415*^9}}]
}, Open  ]],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Conclusion", "Section"],

Cell["", "Spacer"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " offers a comprehensive set of tools for studying discrete calculus at all \
levels."
}], "Item",
 CellChangeTimes->{{3.496065962942893*^9, 3.4960659807744927`*^9}}],

Cell["\<\
The discrete plotting functions and other features will make it easier to \
understand and study sequences.\
\>", "Item",
 CellChangeTimes->{3.4960659907589407`*^9}],

Cell["\<\
We believe that discrete calculus will continue to play a major role in \
education and applications in the  near future.\
\>", "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
Saveable->True,
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1120, 774},
WindowMargins->{{5, Automatic}, {Automatic, 5}},
WindowTitle->"S19 Discrete Calculus with Mathematica",
ShowSelection->True,
Magnification->1.,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", $CellContext`StyleDefnitions -> 
              StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> Plain, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{80, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> Plain, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontColor -> RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             CellMargins -> {{88, 60}, {20, 
              12}}, $CellContext`WholeCellGroupOpener -> True]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {
              LimitsPositioning -> True}, $CellContext`StripStyleOnPaste -> 
             True], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               1.75 Inherited, 1.75 Inherited}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {1.5 Inherited, 1.5 Inherited}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {1.5 Inherited, 1.5 Inherited}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"], FontSize -> 21], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, 
           Closed]]}, Closed]]}, Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, 2010)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[619, 23, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1548, 66, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[2510, 112, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[13149, 501, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[20152, 730, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[29278, 1038, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[39014, 1344, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[47065, 1589, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[52742, 1787, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[61929, 2044, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[70890, 2352, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[77948, 2595, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[81618, 2716, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[85343, 2863, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 119164, 3628}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[619, 23, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[686, 26, 104, 4, 172, "Title"],
Cell[793, 32, 169, 6, 156, "Subtitle"],
Cell[965, 40, 124, 4, 191, "Subsubtitle"],
Cell[1092, 46, 419, 15, 64, "DateSection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1548, 66, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1637, 71, 40, 0, 86, "Section"],
Cell[1680, 73, 46, 0, 46, "Text"],
Cell[CellGroupData[{
Cell[1751, 77, 139, 4, 46, "Item"],
Cell[1893, 83, 75, 0, 46, "Item"],
Cell[1971, 85, 89, 2, 46, "Item"],
Cell[2063, 89, 90, 2, 46, "Item"],
Cell[2156, 93, 123, 3, 46, "Item"],
Cell[2282, 98, 146, 5, 46, "Item"]
}, Open  ]],
Cell[2443, 106, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2510, 112, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2599, 117, 48, 0, 86, "Section"],
Cell[2650, 119, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[2693, 123, 57, 0, 57, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[2775, 127, 137, 3, 46, "Item"],
Cell[2915, 132, 142, 3, 46, "Item"],
Cell[3060, 137, 143, 3, 79, "Item"]
}, Open  ]],
Cell[3218, 143, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[3273, 148, 40, 0, 49, "MoreExamplesSection"],
Cell[3316, 150, 201, 6, 48, "Text"],
Cell[3520, 158, 214, 8, 39, "Input"],
Cell[3737, 168, 284, 6, 51, "MathCaption"],
Cell[4024, 176, 219, 8, 39, "Input"],
Cell[4246, 186, 144, 1, 51, "MathCaption"],
Cell[4393, 189, 511, 14, 39, "Input"],
Cell[4907, 205, 577, 15, 53, "MathCaption"],
Cell[5487, 222, 196, 7, 37, "Input"],
Cell[5686, 231, 212, 8, 37, "Input"],
Cell[5901, 241, 405, 7, 51, "MathCaption"],
Cell[6309, 250, 232, 7, 39, "Input"],
Cell[6544, 259, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[6599, 264, 156, 2, 49, "MoreExamplesSection"],
Cell[6758, 268, 114, 3, 46, "Text"],
Cell[6875, 273, 189, 6, 89, "Input"],
Cell[7067, 281, 162, 5, 79, "Input"],
Cell[7232, 288, 183, 5, 47, "Input"],
Cell[7418, 295, 387, 7, 51, "MathCaption"],
Cell[7808, 304, 619, 20, 82, "Input"],
Cell[8430, 326, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[8485, 331, 158, 2, 49, "MoreExamplesSection"],
Cell[8646, 335, 155, 6, 48, "Text"],
Cell[8804, 343, 141, 4, 79, "Input"],
Cell[8948, 349, 93, 2, 51, "MathCaption"],
Cell[9044, 353, 583, 20, 88, "Input"],
Cell[9630, 375, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[9685, 380, 51, 0, 49, "MoreExamplesSection"],
Cell[9739, 382, 169, 6, 48, "Text"],
Cell[9911, 390, 557, 17, 37, "Input"],
Cell[10471, 409, 329, 10, 37, "Input"],
Cell[10803, 421, 747, 16, 51, "MathCaption"],
Cell[11553, 439, 443, 14, 37, "Input"],
Cell[11999, 455, 304, 8, 37, "Input"],
Cell[12306, 465, 254, 9, 53, "MathCaption"],
Cell[12563, 476, 504, 16, 37, "Input"],
Cell[13070, 494, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13149, 501, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[13238, 506, 41, 0, 86, "Section"],
Cell[13282, 508, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[13325, 512, 51, 0, 57, "MoreExamplesSection"],
Cell[13379, 514, 479, 6, 51, "MathCaption"],
Cell[13861, 522, 283, 9, 43, "Input"],
Cell[14147, 533, 199, 2, 51, "MathCaption"],
Cell[14349, 537, 169, 4, 45, "Input"],
Cell[14521, 543, 240, 7, 48, "Input"],
Cell[14764, 552, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[14819, 557, 51, 0, 49, "MoreExamplesSection"],
Cell[14873, 559, 279, 6, 46, "Text"],
Cell[15155, 567, 721, 13, 53, "MathCaption"],
Cell[15879, 582, 434, 16, 92, "Input"],
Cell[16316, 600, 123, 3, 40, "Input"],
Cell[16442, 605, 158, 4, 45, "Input"],
Cell[16603, 611, 157, 3, 46, "Text"],
Cell[16763, 616, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[16818, 621, 49, 0, 49, "MoreExamplesSection"],
Cell[16870, 623, 701, 16, 53, "MathCaption"],
Cell[17574, 641, 1179, 33, 145, "Input"],
Cell[18756, 676, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[18811, 681, 48, 0, 49, "MoreExamplesSection"],
Cell[18862, 683, 277, 10, 48, "Text"],
Cell[19142, 695, 518, 8, 51, "MathCaption"],
Cell[19663, 705, 195, 6, 78, "Input"],
Cell[19861, 713, 209, 8, 37, "Input"],
Cell[20073, 723, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20152, 730, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[20241, 735, 107, 4, 86, "Section"],
Cell[20351, 741, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[20394, 745, 43, 0, 57, "MoreExamplesSection"],
Cell[20440, 747, 619, 12, 48, "Text"],
Cell[CellGroupData[{
Cell[21084, 763, 147, 2, 46, "Item"],
Cell[21234, 767, 180, 4, 46, "Item"],
Cell[21417, 773, 207, 3, 46, "Item"],
Cell[21627, 778, 157, 6, 48, "Item"]
}, Open  ]],
Cell[21799, 787, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[21854, 792, 52, 0, 49, "MoreExamplesSection"],
Cell[21909, 794, 418, 5, 51, "MathCaption"],
Cell[22330, 801, 215, 7, 67, "Input"],
Cell[22548, 810, 510, 8, 51, "MathCaption"],
Cell[23061, 820, 100, 3, 40, "Input"],
Cell[23164, 825, 239, 7, 87, "MathCaption"],
Cell[23406, 834, 357, 12, 82, "Input"],
Cell[23766, 848, 60, 0, 51, "MathCaption"],
Cell[23829, 850, 137, 4, 45, "Input"],
Cell[23969, 856, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[24024, 861, 42, 0, 49, "MoreExamplesSection"],
Cell[24069, 863, 135, 3, 52, "MathCaption"],
Cell[24207, 868, 334, 13, 100, "Input"],
Cell[24544, 883, 130, 3, 51, "MathCaption"],
Cell[24677, 888, 832, 25, 70, "Text"],
Cell[25512, 915, 117, 3, 51, "MathCaption"],
Cell[25632, 920, 197, 7, 79, "Input"],
Cell[25832, 929, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[25887, 934, 64, 0, 49, "MoreExamplesSection"],
Cell[25954, 936, 760, 14, 53, "MathCaption"],
Cell[26717, 952, 463, 15, 100, "Input"],
Cell[27183, 969, 503, 8, 51, "MathCaption"],
Cell[27689, 979, 294, 10, 85, "Input"],
Cell[27986, 991, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[28041, 996, 49, 0, 49, "MoreExamplesSection"],
Cell[28093, 998, 746, 18, 53, "MathCaption"],
Cell[28842, 1018, 354, 11, 80, "Input"],
Cell[29199, 1031, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29278, 1038, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[29367, 1043, 50, 0, 86, "Section"],
Cell[29420, 1045, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[29463, 1049, 54, 0, 57, "MoreExamplesSection"],
Cell[29520, 1051, 528, 9, 46, "Text"],
Cell[30051, 1062, 240, 6, 51, "MathCaption"],
Cell[30294, 1070, 651, 18, 79, "Input"],
Cell[30948, 1090, 259, 6, 51, "MathCaption"],
Cell[31210, 1098, 597, 16, 79, "Input"],
Cell[31810, 1116, 407, 13, 51, "MathCaption"],
Cell[32220, 1131, 1431, 38, 201, "Input"],
Cell[33654, 1171, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[33709, 1176, 481, 6, 49, "MoreExamplesSection"],
Cell[34193, 1184, 367, 13, 53, "MathCaption"],
Cell[34563, 1199, 170, 5, 71, "Input"],
Cell[34736, 1206, 120, 3, 37, "Input"],
Cell[34859, 1211, 146, 4, 39, "Input"],
Cell[35008, 1217, 657, 11, 51, "MathCaption"],
Cell[35668, 1230, 274, 10, 69, "Input"],
Cell[35945, 1242, 742, 20, 79, "Input"],
Cell[36690, 1264, 242, 8, 47, "Input"],
Cell[36935, 1274, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[36990, 1279, 47, 0, 49, "MoreExamplesSection"],
Cell[37040, 1281, 655, 8, 51, "MathCaption"],
Cell[37698, 1291, 218, 7, 78, "Input"],
Cell[37919, 1300, 261, 5, 51, "MathCaption"],
Cell[38183, 1307, 271, 9, 78, "Input"],
Cell[38457, 1318, 150, 5, 51, "Input"],
Cell[38610, 1325, 322, 10, 39, "Input"],
Cell[38935, 1337, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39014, 1344, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[39103, 1349, 52, 0, 86, "Section"],
Cell[39158, 1351, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[39201, 1355, 538, 7, 57, "MoreExamplesSection"],
Cell[39742, 1364, 763, 16, 48, "Text"],
Cell[CellGroupData[{
Cell[40530, 1384, 185, 4, 46, "Item"],
Cell[40718, 1390, 262, 5, 46, "Item"],
Cell[40983, 1397, 187, 4, 46, "Item"]
}, Open  ]],
Cell[41185, 1404, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[41240, 1409, 60, 0, 49, "MoreExamplesSection"],
Cell[41303, 1411, 122, 3, 51, "MathCaption"],
Cell[41428, 1416, 638, 20, 71, "Input"],
Cell[42069, 1438, 577, 16, 68, "Input"],
Cell[42649, 1456, 260, 9, 52, "Input"],
Cell[42912, 1467, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[42967, 1472, 131, 1, 49, "MoreExamplesSection"],
Cell[43101, 1475, 424, 5, 51, "MathCaption"],
Cell[43528, 1482, 1074, 30, 76, "Input"],
Cell[44605, 1514, 538, 8, 51, "MathCaption"],
Cell[45146, 1524, 887, 26, 46, "Input"],
Cell[46036, 1552, 170, 5, 37, "Input"],
Cell[46209, 1559, 774, 21, 76, "Input"],
Cell[46986, 1582, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47065, 1589, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[47154, 1594, 59, 0, 86, "Section"],
Cell[47216, 1596, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[47259, 1600, 56, 0, 57, "MoreExamplesSection"],
Cell[47318, 1602, 136, 1, 46, "Text"],
Cell[47457, 1605, 179, 2, 46, "Text"],
Cell[47639, 1609, 211, 8, 44, "DisplayFormula"],
Cell[47853, 1619, 190, 7, 48, "Text"],
Cell[48046, 1628, 307, 6, 46, "Text"],
Cell[48356, 1636, 189, 5, 47, "Text"],
Cell[48548, 1643, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[48603, 1648, 58, 0, 49, "MoreExamplesSection"],
Cell[48664, 1650, 289, 9, 52, "MathCaption"],
Cell[CellGroupData[{
Cell[48978, 1663, 271, 9, 37, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellID->355890892],
Cell[49252, 1674, 562, 17, 69, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[49817, 1693, 652, 20, 47, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[50472, 1715, 1517, 43, 87, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[51992, 1760, 656, 17, 109, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[52663, 1780, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52742, 1787, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[52831, 1792, 39, 0, 86, "Section"],
Cell[52873, 1794, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[52916, 1798, 441, 5, 57, "MoreExamplesSection"],
Cell[53360, 1805, 212, 5, 53, "MathCaption"],
Cell[53575, 1812, 281, 8, 37, "Input"],
Cell[53859, 1822, 277, 8, 37, "Input"],
Cell[54139, 1832, 254, 7, 37, "Input"],
Cell[54396, 1841, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[54451, 1846, 441, 5, 49, "MoreExamplesSection"],
Cell[54895, 1853, 645, 10, 51, "MathCaption"],
Cell[55543, 1865, 276, 8, 37, "Input",
 CellID->181474481],
Cell[55822, 1875, 196, 7, 37, "Input",
 CellID->118063561],
Cell[56021, 1884, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[56076, 1889, 69, 0, 49, "MoreExamplesSection"],
Cell[56148, 1891, 683, 10, 52, "MathCaption"],
Cell[56834, 1903, 731, 20, 65, "Input"],
Cell[57568, 1925, 699, 10, 51, "MathCaption"],
Cell[58270, 1937, 400, 13, 65, "Input"],
Cell[58673, 1952, 127, 3, 37, "Input"],
Cell[58803, 1957, 220, 7, 83, "Input"],
Cell[59026, 1966, 878, 16, 53, "MathCaption"],
Cell[59907, 1984, 230, 7, 65, "Input"],
Cell[60140, 1993, 725, 11, 51, "MathCaption"],
Cell[60868, 2006, 979, 29, 105, "Input"],
Cell[61850, 2037, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61929, 2044, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[62018, 2049, 64, 0, 86, "Section"],
Cell[62085, 2051, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[62128, 2055, 58, 0, 57, "MoreExamplesSection"],
Cell[62189, 2057, 108, 4, 73, "Text"],
Cell[62300, 2063, 402, 13, 98, "DisplayFormula"],
Cell[62705, 2078, 145, 5, 73, "Text"],
Cell[62853, 2085, 799, 26, 66, "DisplayFormula"],
Cell[63655, 2113, 138, 4, 73, "Text"],
Cell[63796, 2119, 203, 6, 41, "DisplayFormula"]
}, Closed]],
Cell[CellGroupData[{
Cell[64036, 2130, 52, 0, 49, "MoreExamplesSection"],
Cell[64091, 2132, 185, 4, 46, "Text"],
Cell[64279, 2138, 289, 7, 73, "Text"],
Cell[64571, 2147, 1018, 33, 66, "DisplayFormula"]
}, Closed]],
Cell[CellGroupData[{
Cell[65626, 2185, 69, 0, 49, "MoreExamplesSection"],
Cell[65698, 2187, 146, 5, 53, "MathCaption"],
Cell[65847, 2194, 476, 15, 63, "Input"],
Cell[66326, 2211, 346, 11, 52, "Input"],
Cell[66675, 2224, 139, 1, 51, "MathCaption"],
Cell[66817, 2227, 135, 4, 45, "Input"],
Cell[66955, 2233, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[67010, 2238, 85, 1, 49, "MoreExamplesSection"],
Cell[67098, 2241, 736, 11, 51, "MathCaption"],
Cell[67837, 2254, 2705, 82, 179, "Input"],
Cell[70545, 2338, 263, 5, 46, "Text"],
Cell[70811, 2345, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[70890, 2352, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[70979, 2357, 41, 0, 86, "Section"],
Cell[71023, 2359, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[71066, 2363, 426, 5, 57, "MoreExamplesSection"],
Cell[71495, 2370, 64, 0, 46, "Text"],
Cell[CellGroupData[{
Cell[71584, 2374, 151, 4, 46, "Item"],
Cell[71738, 2380, 121, 3, 46, "Item"],
Cell[71862, 2385, 119, 3, 46, "Item"]
}, Open  ]],
Cell[71996, 2391, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[72051, 2396, 612, 8, 49, "MoreExamplesSection"],
Cell[72666, 2406, 250, 5, 46, "Text"],
Cell[72919, 2413, 239, 5, 51, "MathCaption"],
Cell[73161, 2420, 355, 12, 82, "Input"],
Cell[73519, 2434, 351, 11, 72, "Input"],
Cell[73873, 2447, 123, 3, 52, "MathCaption"],
Cell[73999, 2452, 543, 19, 116, "Input"],
Cell[74545, 2473, 620, 21, 73, "Input"],
Cell[75168, 2496, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[75223, 2501, 398, 5, 49, "MoreExamplesSection"],
Cell[75624, 2508, 256, 10, 48, "Text"],
Cell[75883, 2520, 160, 6, 48, "Text"],
Cell[76046, 2528, 301, 6, 51, "MathCaption"],
Cell[76350, 2536, 468, 14, 104, "Input"],
Cell[76821, 2552, 95, 2, 39, "Input"],
Cell[76919, 2556, 479, 13, 53, "MathCaption"],
Cell[77401, 2571, 298, 8, 37, "Input"],
Cell[77702, 2581, 164, 5, 83, "Input"],
Cell[77869, 2588, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[77948, 2595, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[78037, 2600, 42, 0, 86, "Section"],
Cell[78082, 2602, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[78125, 2606, 60, 0, 57, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[78210, 2610, 372, 12, 50, "Item"],
Cell[78585, 2624, 410, 7, 46, "Item"],
Cell[78998, 2633, 496, 9, 46, "Item"],
Cell[79497, 2644, 319, 6, 46, "Item"]
}, Open  ]],
Cell[79831, 2653, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[79886, 2658, 57, 0, 49, "MoreExamplesSection"],
Cell[79946, 2660, 40, 0, 46, "Text"],
Cell[79989, 2662, 500, 15, 37, "Input"],
Cell[80492, 2679, 210, 3, 51, "MathCaption"],
Cell[80705, 2684, 223, 6, 37, "Input"],
Cell[80931, 2692, 255, 3, 51, "MathCaption"],
Cell[81189, 2697, 347, 10, 45, "Input"],
Cell[81539, 2709, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[81618, 2716, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[81707, 2721, 72, 0, 86, "Section"],
Cell[81782, 2723, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[81825, 2727, 64, 0, 57, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[81914, 2731, 342, 6, 79, "Item"],
Cell[82259, 2739, 91, 2, 46, "Item"],
Cell[82353, 2743, 354, 11, 81, "Item"]
}, Open  ]],
Cell[82722, 2757, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[82777, 2762, 46, 0, 49, "MoreExamplesSection"],
Cell[82826, 2764, 148, 5, 46, "Text"],
Cell[82977, 2771, 150, 3, 73, "Text"],
Cell[83130, 2776, 266, 8, 53, "MathCaption"],
Cell[83399, 2786, 75, 2, 37, "Input"],
Cell[83477, 2790, 320, 8, 53, "MathCaption"],
Cell[83800, 2800, 87, 2, 37, "Input"],
Cell[83890, 2804, 335, 8, 53, "MathCaption"],
Cell[84228, 2814, 82, 2, 37, "Input"],
Cell[84313, 2818, 18, 0, 20, "Spacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[84368, 2823, 66, 0, 49, "MoreExamplesSection"],
Cell[84437, 2825, 215, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[84677, 2835, 323, 11, 48, "Item"],
Cell[85003, 2848, 246, 5, 46, "Item"]
}, Open  ]],
Cell[85264, 2856, 18, 0, 20, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85343, 2863, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[85432, 2868, 29, 0, 86, "Section"],
Cell[85464, 2870, 18, 0, 20, "Spacer"],
Cell[CellGroupData[{
Cell[85507, 2874, 232, 6, 46, "Item"],
Cell[85742, 2882, 175, 4, 46, "Item"],
Cell[85920, 2888, 145, 3, 46, "Item"]
}, Open  ]],
Cell[86080, 2894, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
